@@ -35,9 +35,9 @@ class LoginPageView(TemplateView):
         return render(request, self.template_name)
 
     def post(self, request, *args, **kwargs):
-        username = request.POST.get('username')
+        email = request.POST.get('email')
         password = request.POST.get('password')
-        user = authenticate(request, username=username, password=password)
+        user = authenticate(request, email=email, password=password)
 
         if user is not None:
             login(request, user)
@@ -48,7 +48,7 @@ class LoginPageView(TemplateView):
             self.template_name,
             {
                 'error_message':
-                'Username or password is incorrect'
+                'Email or password is incorrect'
             }
         )
 
